[][src]Trait wait_timeout::ChildExt

pub trait ChildExt {
    fn wait_timeout(&mut self, dur: Duration) -> Result<Option<ExitStatus>>;
}

Extension methods for the standard std::process::Child type.

Required methods

fn wait_timeout(&mut self, dur: Duration) -> Result<Option<ExitStatus>>

Wait for this child to exit, timing out after the duration dur has elapsed.

If Ok(None) is returned then the timeout period elapsed without the child exiting, and if Ok(Some(..)) is returned then the child exited with the specified exit code.

Loading content...

Implementations on Foreign Types

impl ChildExt for Child[src]

Loading content...

Implementors

Loading content...